searchNodes=[{"ref":"JsonXema.html","title":"JsonXema","type":"module","doc":"A JSON Schema validator."},{"ref":"JsonXema.html#new/2","title":"JsonXema.new/2","type":"function","doc":"This function creates a new JsonXema from the given schema. Possible options: :loader - a loader for remote schemas. This option will overwrite the loader from the config. See [Configure a loader](loader.html) to how to define a loader. Examples iex&gt; ~s({&quot;type&quot;: &quot;string&quot;}) ...&gt; |&gt; Jason.decode!() ...&gt; |&gt; JsonXema.new() %JsonXema{refs: %{}, schema: %Xema.Schema{type: :string}}"},{"ref":"JsonXema.html#to_xema/1","title":"JsonXema.to_xema/1","type":"function","doc":"Converts %JsonXema{} to %Xema{}."},{"ref":"JsonXema.html#valid?/2","title":"JsonXema.valid?/2","type":"function","doc":"Returns true if the value is a valid value against the given schema; otherwise returns false."},{"ref":"JsonXema.html#validate/2","title":"JsonXema.validate/2","type":"function","doc":"Returns :ok if the value is a valid value against the given schema; otherwise returns an error tuple."},{"ref":"JsonXema.html#validate!/2","title":"JsonXema.validate!/2","type":"function","doc":"Returns :ok if the value is a valid value against the given schema; otherwise raises a Elixir.JsonXema.ValidationError."},{"ref":"JsonXema.html#t:t/0","title":"JsonXema.t/0","type":"type","doc":"This struct contains the schema and references of the schema."},{"ref":"JsonXema.SchemaError.html","title":"JsonXema.SchemaError","type":"exception","doc":"Raised when a schema can&#39;t be build."},{"ref":"JsonXema.ValidationError.html","title":"JsonXema.ValidationError","type":"exception","doc":"Raised when a validation fails. Example iex&gt; schema = JsonXema.new(%{&quot;type&quot; =&gt; &quot;string&quot;}) iex&gt; {:error, error} = JsonXema.validate(schema, 6) iex&gt; Exception.message(error) ~s|Expected &quot;string&quot;, got 6.|"},{"ref":"JsonXema.ValidationError.html#format_error/1","title":"JsonXema.ValidationError.format_error/1","type":"function","doc":"This function returns an error message for an error or error tuple. Example iex&gt; schema = JsonXema.new(%{&quot;type&quot; =&gt; &quot;integer&quot;}) iex&gt; schema ...&gt; |&gt; JsonXema.validate(1.1) ...&gt; |&gt; JsonXema.ValidationError.format_error() ~s|Expected &quot;integer&quot;, got 1.1.|"},{"ref":"JsonXema.ValidationError.html#travers_errors/4","title":"JsonXema.ValidationError.travers_errors/4","type":"function","doc":"Traverse the error tree and invokes the given function. Example iex&gt; fun = fn _error, path, acc -&gt; ...&gt; [&quot;Error at &quot; &lt;&gt; inspect(path) | acc] ...&gt; end iex&gt; iex&gt; schema = JsonXema.new(%{ ...&gt; &quot;properties&quot; =&gt; %{ ...&gt; &quot;int&quot; =&gt; %{&quot;type&quot; =&gt; &quot;integer&quot;}, ...&gt; &quot;names&quot; =&gt; %{ ...&gt; &quot;type&quot; =&gt; &quot;array&quot;, ...&gt; &quot;items&quot; =&gt; %{&quot;type&quot; =&gt; &quot;string&quot;} ...&gt; }, ...&gt; &quot;num&quot; =&gt; %{&quot;anyOf&quot; =&gt; [ ...&gt; %{&quot;type&quot; =&gt; &quot;integer&quot;}, ...&gt; %{&quot;type&quot; =&gt; &quot;number&quot;} ...&gt; ]} ...&gt; } ...&gt; }) iex&gt; iex&gt; data = %{&quot;int&quot; =&gt; &quot;x&quot;, &quot;names&quot; =&gt; [1, &quot;x&quot;, 5], &quot;num&quot; =&gt; :foo} iex&gt; iex&gt; schema ...&gt; |&gt; JsonXema.validate(data) ...&gt; |&gt; JsonXema.ValidationError.travers_errors([], fun) [ ~s|Error at [&quot;num&quot;]|, ~s|Error at [&quot;names&quot;, 2]|, ~s|Error at [&quot;names&quot;, 0]|, ~s|Error at [&quot;names&quot;]|, ~s|Error at [&quot;int&quot;]|, ~s|Error at []| ]"},{"ref":"JsonXema.ValidationError.html#t:opts/0","title":"JsonXema.ValidationError.opts/0","type":"type","doc":""},{"ref":"JsonXema.ValidationError.html#t:path/0","title":"JsonXema.ValidationError.path/0","type":"type","doc":""},{"ref":"readme.html","title":"JsonXema","type":"extras","doc":"JsonXema JsonXema is a JSON Schema validator with support for draft 04, 06, and 07. JsonXema based on elixir schema validator Xema. JsonXema is in early beta. If you try it and has an issue, report them."},{"ref":"usage.html","title":"Usage","type":"extras","doc":"Usage A JSON parser is required to create a schema from JSON. It is also possible to create a schema directly from an elixir data structure. There are three functions available to validate data against a schema. JsonXema.valid?/2 gets a schema and any data and returns true for valid data and false otherwise. JsonXema.validate/2 gets a schema and any data and returns :ok for valid data and an error tuple otherwise. JsonXema.validate!/2 gets a schema and any data and returns :ok for valid data and raised an exception otherwise. iex&gt; schema = &quot;&quot;&quot; ...&gt; { ...&gt; &quot;type&quot;: &quot;object&quot;, ...&gt; &quot;properties&quot;: { ...&gt; &quot;name&quot;: { ...&gt; &quot;type&quot;: &quot;string&quot;, ...&gt; &quot;min_length&quot;: 3 ...&gt; }, ...&gt; &quot;age&quot;: { ...&gt; &quot;type&quot;: &quot;integer&quot;, ...&gt; &quot;minimum&quot;: 0 ...&gt; } ...&gt; }, ...&gt; &quot;additionalProperties&quot;: false ...&gt; } ...&gt; &quot;&quot;&quot; ...&gt; |&gt; Jason.decode!() ...&gt; |&gt; JsonXema.new() ...&gt; ...&gt; data = Jason.decode!(&quot;&quot;&quot; ...&gt; {&quot;name&quot;: &quot;John&quot;, &quot;age&quot;: 42} ...&gt; &quot;&quot;&quot;) ...&gt; JsonXema.valid?(schema, data) true ...&gt; JsonXema.valid?(schema, %{&quot;name&quot; =&gt; &quot;Peter&quot;, &quot;age&quot; =&gt; -55}) false ...&gt; JsonXema.valid?(schema, %{&quot;name&quot; =&gt; &quot;Peter&quot;, &quot;old&quot; =&gt; 55}) false ...&gt; JsonXema.validate(schema, %{&quot;name&quot; =&gt; &quot;Peter&quot;, &quot;age&quot; =&gt; -55}) {:error, %JsonXema.ValidationError{ reason: %{properties: %{&quot;age&quot; =&gt; %{minimum: 0, value: -55}}}}} ...&gt; JsonXema.validate(schema, %{&quot;name&quot; =&gt; &quot;Peter&quot;, &quot;old&quot; =&gt; 55}) {:error, %JsonXema.ValidationError{ reason: %{properties: %{&quot;old&quot; =&gt; %{additionalProperties: false}}}}}"},{"ref":"loader.html","title":"Configure a loader","type":"extras","doc":"Configure a loader A loader returns the data for a remote schema. The remote schemas are defined in a schema like this. ... &quot;properties&quot;: { &quot;int&quot;: {&quot;$ref&quot;: &quot;http://localhost:1234/int.json&quot;} } ... A loader will be configured like this. config :xema, loader: My.Loader A loader is a module which use the behaviour Xema.Loader. defmodule My.Loader do @moduledoc false @behaviour Xema.Loader @spec fetch(URI.t()) :: {:ok, any} | {:error, any} def fetch(uri) do case HTTPoison.get(uri) do {:ok, %HTTPoison.Response{status_code: 200, body: body}} -&gt; {:ok, Jason.decode!(body)} {:ok, %HTTPoison.Response{status_code: 404}} -&gt; {:error, &quot;Remote schema &#39;\#{uri}&#39; not found.&quot;} {:ok, %HTTPoison.Response{status_code: code}} -&gt; {:error, &quot;HTTP Error - code: \#{code}&quot;} {:error, reason} -&gt; {:error, reason} end end end The function fetch/1 will be called by Xema and expects an %URI{}. The return value must be a tuple of :ok and the required data for a schema or an error tuple."},{"ref":"loader.html#file-loader","title":"Configure a loader - File loader","type":"extras","doc":"A loader to read schema from the local file system. In the schema: ... &quot;properties&quot;: { &quot;int&quot;: {&quot;$ref&quot;: &quot;integer.json&quot;} } ... The loader: defmodule My.Loader do @moduledoc false @behaviour Xema.Loader @spec fetch(URI.t()) :: {:ok, any} | {:error, any} def fetch(uri), do: &quot;path/to/schemas&quot; |&gt; Path.join(uri.path) |&gt; File.read!() |&gt; Jason.decode() end"},{"ref":"unsupported.html","title":"Unsupported","type":"extras","doc":"Unsupported Some of the optional JSON-Schema features are not supported by JsonXema."},{"ref":"unsupported.html#unsupported-semantic-validation","title":"Unsupported - Unsupported semantic validation","type":"extras","doc":"For now, the keyword format do not support the following formats: idn-email the I18N equivalent of email idn-hostname I18N equivalent of hostname iri the I18N equivalent of uri iri-reference the I18N equivalent of uri-reference"}]